<?php
/**
 * Plugin Name:       BSW Blocks
 * Plugin URI:        https://gitlab.bayard-service.com/wordpress/plugins/bsw-blocks
 * Description:       Des blocks pour wordpress
 * Requires at least: 6.1
 * Requires PHP:      7.0
 * Version:           1.3.5
 * Author:            Bayard Service
 * License:           GPL-2.0-or-later
 * License URI:       https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain:       bsw-blocks
 * Domain Path:       bsw-blocks
 *
 * @package           bsw-blocks
 */

/**
 * Registers the block using the metadata loaded from the `block.json` file.
 * Behind the scenes, it registers also all assets so they can be enqueued
 * through the block editor in the corresponding context.
 *
 * @see https://developer.wordpress.org/reference/functions/register_block_type/
 */




function bsw_blocks_init() {
	// Vérifie si le plugin ACF est activé
	if ( ! is_plugin_active('advanced-custom-fields/acf.php')) {
		// Affiche un message d'erreur indiquant que le plugin ACF doit être activé
		add_action('admin_notices', 'bsw_blocks_acf_dependency_notice');
	}
}

function bsw_blocks_acf_dependency_notice() {
	$message = "Le plugin ACF doit être activé pour utiliser le plugin BSW Blocks. Veuillez l'installer et l'activer depuis la page des extensions.";
	echo '<div class="error"><p>' . $message . '</p></div>';
}
add_action( 'admin_init', 'bsw_blocks_init' );

include_once( ABSPATH .'wp-admin/includes/plugin.php' );

function bsw_blocks_block_init() {
	$blocks = array(
		'random-image',
		'slider',
		'child-posts',
		'siblings-posts',
		'related-posts',
		'accordion',
		'slider-static/slider',
		'slider-static/slide',
		'related-posts-template',
		is_plugin_active( 'the-events-calendar/the-events-calendar.php' )?'event-list':null,
	);
	foreach ( $blocks as $block ) {
		register_block_type( __DIR__ . '/build/' . $block );
	}

}

add_action( 'init', 'bsw_blocks_block_init' );

require_once( 'includes/plugin-update-checker/plugin-update-checker.php' );

use YahnisElsts\PluginUpdateChecker\v5p0\Vcs\GitLabApi;
use YahnisElsts\PluginUpdateChecker\v5p0\Vcs\PluginUpdateChecker;

$myUpdateChecker = new PluginUpdateChecker(
	new GitLabApi(
		'https://gitlab.bayard-service.com/wordpress/plugins/bsw-blocks/',
		'glpat--MKCqQco38yx3Qegwv1k',
		'plugins'
	),
	__FILE__,
	'bsw-blocks'
);

// Stratégie par défaut : on va regarder si une release plus récente existe
$myUpdateChecker->getVcsApi()->enableReleaseAssets();


function bsw_blocks_call_scripts_accordion()
{
	wp_enqueue_script(
		'jquery-ui',
		plugins_url('public/jquery-ui/jquery-ui.js', __FILE__),
		array('jquery'),
		filemtime(plugin_dir_path(__File__) . 'public/jquery-ui/jquery-ui.js')
	);
	wp_enqueue_script(
		'custom-accordion',
		plugins_url('public/accordion.js', __FILE__),
		array('jquery'),
		filemtime(plugin_dir_path(__File__) . 'public/accordion.js')
	);
}

function bsw_blocks_call_scripts_slider_static(){
	wp_enqueue_script(
		'custom-splide',
		plugins_url('public/splide.js', __FILE__),
		array('jquery'),
		filemtime(plugin_dir_path(__File__) . 'public/splide.js')
	);

}

function bsw_blocks_call_scripts_slider()
{
	wp_enqueue_script(
		'splide',
		plugins_url('public/splidejs/js/splide.min.js', __FILE__),
		array('jquery'),
		filemtime(plugin_dir_path(__File__) . 'public/splidejs/js/splide.min.js')
	);

	wp_enqueue_style(
		'splide',
		plugins_url('public/splidejs/css/splide.min.css', __FILE__),
		array(),
		filemtime(plugin_dir_path(__File__) . 'public/splidejs/css/splide.min.css')
	);

}

add_filter('render_block', function ($block_content, $block) {
	// Make sure we have the blockName.
	if (empty($block['blockName'])) {
		return $block_content;
	}

	// Appel des librairies pour le slider
	if (
		'bsw/slider' === $block['blockName'] ||
		'bsw/slider-static' === $block['blockName']
	) {
		bsw_blocks_call_scripts_slider();
	}

	//Appel des librairies pour le slider static
	if('bsw/slider-static' === $block['blockName']){
		bsw_blocks_call_scripts_slider_static();
	}

	// Appel des librairies pour l'accordéon
	if (
		'bsw/accordion' === $block['blockName']
	) {
		bsw_blocks_call_scripts_accordion();
	}

	// Return the block content.
	return $block_content;
}, 10, 2);











