/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { InnerBlocks, useBlockProps } from '@wordpress/block-editor';

/**
 * The save function defines the way in which the different attributes should
 * be combined into the final markup, which is then serialized by the block
 * editor into `post_content`.
 *
 * @param {Object} props
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#save
 *
 * @return {WPElement} Element to render.
 */
export default function save(props) {
	const { attributes } = props;
	const { title, openByDefault, htmlTag } = attributes;

	const HtmlTag = htmlTag;
	const blockProps = useBlockProps.save({
		className: openByDefault === true ? 'open' : '',
	});

	return (
		<div {...blockProps}>
			<HtmlTag>{title}</HtmlTag>
			<div className={'accordion-content'}>
				<InnerBlocks.Content />
			</div>
		</div>
	);
}
