import { useSelect } from '@wordpress/data';
import { useBlockProps } from '@wordpress/block-editor';

export default function Block(props) {
	const blockProps = useBlockProps();
	const {
		showExcerpt,
		showThumbnail,
		thumbnailSize,
		htmlTag,
		idTagName,
		idCategorieName,
	} = props;

	const args = {
		per_page: -1,
		tribe_events_cat:
			idCategorieName !== undefined && idCategorieName !== 'Aucun'
				? idCategorieName
				: [],
		tags: idTagName !== undefined && idTagName !== 'Aucun' ? idTagName : [],
	};

	const events = useSelect((select) => {
		const allPosts = [];

		//Get all pages from a parent page
		const posts = select('core').getEntityRecords(
			'postType',
			'tribe_events',
			args
		);
		//Create an array of objects with all the information that we need
		if (posts) {
			posts.forEach(function (element) {
				//Get a media
				const media = select('core').getMedia(element.featured_media);
				const startDate = new Date(element.meta['_EventStartDate']);
				const endDate = new Date(element.meta['_EventEndDate']);
				const object = {
					title: element.title.rendered,
					excerpt: element.excerpt.rendered,
					link: element.link,
					startDateHour: element.meta['_EventStartDate'],
					startDateFormat: startDate.toLocaleDateString(),
					startHour: `${startDate.getHours()}h${String(
						startDate.getMinutes()
					).padStart(2, '0')}`,
					endDateHour: element.meta['_EventEndDate'],
					endDateFormat: endDate.toLocaleDateString(),
					endHour: `${endDate.getHours()}h${String(
						endDate.getMinutes()
					).padStart(2, '0')}`,
					allDay: element.meta['_EventAllDay'],
				};
				if (media && thumbnailSize) {
					object.image = media.media_details.sizes[thumbnailSize]
						? media.media_details.sizes[thumbnailSize].source_url
						: media.media_details.sizes.full.source_url;
					object.imageAlt = media.alt_text;
				}
				allPosts.push(object);
			});

			return allPosts;
		}
	});

	const HtmlTag = htmlTag;

	return (
		<div {...blockProps}>
			<div>
				<ul>
					{events &&
						events.map((element) => (
							<li key={element.title}>
								{element.image && showThumbnail && (
									<figure>
										<img
											src={element.image}
											alt={element.imageAlt}
										/>
									</figure>
								)}
								<HtmlTag>{element.title}</HtmlTag>
								{element.excerpt && showExcerpt && (
									<div
										dangerouslySetInnerHTML={{
											__html: element.excerpt,
										}}
									></div>
								)}
								{element.startDateFormat ===
									element.endDateFormat &&
									element.allDay && (
										<p>
											Le{' '}
											<time
												className={'start_date'}
												dateTime={element.startDateHour}
											>
												{element.startDateFormat}
											</time>
										</p>
									)}
								{element.startDateFormat ===
									element.endDateFormat &&
									element.allDay === false && (
										<p>
											Le{' '}
											<time
												className={'start_date'}
												dateTime={element.startDateHour}
											>
												{element.startDateFormat}
											</time>{' '}
											de{' '}
											<time className={'start_hour'}>
												{element.startHour}
											</time>{' '}
											à{' '}
											<time
												className={'end_hour'}
												dateTime={element.endDateHour}
											>
												{element.endHour}
											</time>
										</p>
									)}
								{element.startDateFormat !==
									element.endDateFormat &&
									element.allDay === false && (
										<p>
											Du{' '}
											<time
												className={'start_date'}
												dateTime={element.startDateHour}
											>
												{element.startDateFormat}
											</time>{' '}
											à{' '}
											<time className={'start_hour'}>
												{element.startHour}
											</time>{' '}
											au{' '}
											<time
												className={'end_date'}
												dateTime={element.endDateHour}
											>
												{element.endDateFormat}
											</time>{' '}
											à{' '}
											<time className={'end_hour'}>
												{element.endHour}
											</time>
										</p>
									)}
								{element.startDateFormat !==
									element.endDateFormat &&
									element.allDay && (
										<p>
											Du{' '}
											<time
												className={'start_date'}
												dateTime={element.startDateHour}
											>
												{element.startDateFormat}
											</time>{' '}
											au{' '}
											<time
												className={'end_date'}
												dateTime={element.endDateHour}
											>
												{element.endDateFormat}
											</time>
										</p>
									)}
							</li>
						))}
				</ul>
			</div>
		</div>
	);
}
