import {
	BlockIcon,
	MediaPlaceholder,
	useBlockProps,
} from '@wordpress/block-editor';
import { ToolbarButton } from '@wordpress/components';
import { Fragment } from '@wordpress/element';
import { __ } from '@wordpress/i18n';

export default function Block(props) {
	const blockProps = useBlockProps();
	const { images, thumbnailSize, showCaption, setAttributes } = props;
	const hasImages = images.length > 0;

	return (
		<Fragment>
			{hasImages ? (
				<figure {...blockProps}>
					<img
						src={
							images[0].sizes[thumbnailSize]
								? images[0].sizes[thumbnailSize].url
								: images[0].sizes.full.url
						}
						alt={images[0].alt}
					/>
					{showCaption && (
						<figcaption>{images[0].caption}</figcaption>
					)}
				</figure>
			) : (
				<MediaPlaceholder
					multiple
					addToGallery={true}
					allowedTypes={['image']}
					gallery
					icon={<BlockIcon icon="format-gallery" />}
					labels={{
						title: 'Image aléatoire',
						instructions:
							'Affiche une image aléatoire parmi une sélection.',
					}}
					onSelect={(newImages) =>
						setAttributes({ images: newImages })
					}
					render={({ open }) => (
						<ToolbarButton onClick={open}>
							{__('Edit')}
						</ToolbarButton>
					)}
				/>
			)}
		</Fragment>
	);
}
