import { useSelect } from '@wordpress/data';
import { useBlockProps } from '@wordpress/block-editor';

export default function Block(props) {
	const blockProps = useBlockProps();
	const {
		showExcerpt,
		showThumbnail,
		thumbnailSize,
		orderBy,
		showCurrentPage,
		htmlTag,
	} = props;
	let currentPostId;
	const siblingPosts = useSelect((select) => {
		const allPosts = [];

		const parentPostId = select('core/editor').getCurrentPost().parent;
		//Get the Id of the current Post
		currentPostId = select('core/editor').getCurrentPostId();
		//Get post type of Current post
		const currentPostType = select('core/editor').getCurrentPostType();

		//Get all pages from a parent page

		const sibling = select('core').getEntityRecords(
			'postType',
			currentPostType,
			{
				parent: parentPostId,
				exclude: showCurrentPage ? '' : currentPostId,
				order_by: orderBy,
				order: 'asc',
				per_page: -1,
			}
		);

		//Create an array of objects with all the information that we need
		if (sibling) {
			sibling.forEach(function (element) {
				//Get a media
				const media = select('core').getMedia(element.featured_media);

				const object = {
					id: element.id,
					title: element.title.rendered,
					excerpt: element.excerpt.rendered,
					link: element.link,
				};
				if (media && thumbnailSize) {
					object.image = media.media_details.sizes[thumbnailSize]
						? media.media_details.sizes[thumbnailSize].source_url
						: media.media_details.sizes.full.source_url;
					object.imageAlt = media.alt_text;
				}
				allPosts.push(object);
			});
			return allPosts;
		}
	});

	const HtmlTag = htmlTag;

	return (
		<div {...blockProps}>
			{siblingPosts && siblingPosts.length > 0 ? (
				<ul>
					{siblingPosts &&
						siblingPosts.map((element) => (
							<li
								key={element.id}
								className={
									element.id === currentPostId
										? 'current'
										: ''
								}
							>
								{element.image && showThumbnail && (
									<figure>
										<img
											src={element.image}
											alt={element.imageAlt}
										/>
									</figure>
								)}
								<HtmlTag>{element.title}</HtmlTag>
								{element.excerpt && showExcerpt && (
									<div
										dangerouslySetInnerHTML={{
											__html: element.excerpt,
										}}
									></div>
								)}
							</li>
						))}
				</ul>
			) : (
				<p className={'no-content'}>
					Affichage de la liste des pages soeurs
				</p>
			)}
		</div>
	);
}
