/**
 * Retrieves the translation of text.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-i18n/
 */
/**
 * React hook that is used to mark the block wrapper element.
 * It provides all the necessary props like the class name.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/packages/packages-block-editor/#useblockprops
 */
import { useBlockProps } from '@wordpress/block-editor';
import Inspector from './inspector';

import { useSelect } from '@wordpress/data';

/**
 * Lets webpack process CSS, SASS or SCSS files referenced in JavaScript files.
 * Those files can contain any CSS code that gets applied to the editor.
 *
 * @see https://www.npmjs.com/package/@wordpress/scripts#using-css
 */
import './editor.scss';

import { Fragment } from '@wordpress/element';

/**
 * The edit function describes the structure of your block in the context of the
 * editor. This represents what the editor will render when the block is used.
 *
 * @see https://developer.wordpress.org/block-editor/reference-guides/block-api/block-edit-save/#edit
 *
 * @return {WPElement} Element to render.
 */
import { useSetting } from '@wordpress/block-editor';

export default function Edit(props) {
	const { attributes, setAttributes, clientId } = props;
	const {
		postType,
		interval,
		orderBy,
		showThumbnail,
		showExcerpt,
		showTags,
		showCategories,
		perPage,
		nombrePosts,
		perMove,
		autoplay,
		showArrows,
		showPagination,
		tagName,
		categorieName,
		idCategorieName,
		idTagName,
		tagsList,
		categoriesList,
		categoriesListOfCurrentPost,
		tagsListOfCurrentPost,
		allPostType,
		thumbnailSize,
		padding,
		perMoveMobile,
		perPageMobile,
		paddingMobile,
		excludeCurrentPage,
		readMore,
		linkTitle,
		blockId,
		margin,
		showStartDate,
		showEndDate,
	} = attributes;

	if (!blockId) {
		setAttributes({ blockId: clientId });
	}

	const marginData = useSetting('custom.margin-text');
	if (!margin) {
		setAttributes({ margin: marginData });
	}

	const blockProps = useBlockProps({
		className: 'splide',
		id: blockId,
	});

	const currentPostId = useSelect((select) => {
		return select('core/editor').getCurrentPostId();
	});

	const query = useSelect((select) => {
		return select('core');
	});

	let args;

	if (postType === 'temoignage') {
		args = {
			per_page: -1,
			exclude: excludeCurrentPage ? currentPostId : null,
			tags:
				idTagName !== undefined && idTagName !== 'Aucun'
					? idTagName
					: [],
			categories:
				idCategorieName !== undefined && idCategorieName !== 'Aucun'
					? idCategorieName
					: [],
		};
	} else if (postType === 'tribe_events') {
		args = {
			per_page: -1,
			tags:
				idTagName !== undefined && idTagName !== 'Aucun'
					? idTagName
					: [],
			tribe_events_cat:
				idCategorieName !== undefined && idCategorieName !== 'Aucun'
					? idCategorieName
					: [],
		};
	} else {
		args = {
			per_page: -1,
			tags:
				idTagName !== undefined && idTagName !== 'Aucun'
					? idTagName
					: [],
			categories:
				idCategorieName !== undefined && idCategorieName !== 'Aucun'
					? idCategorieName
					: [],
		};
	}

	const posts = query.getEntityRecords('postType', postType, args);

	if (posts && posts[0]) {
		const tagsOfPost = posts[0].tags;
		const arrayOfTag = [];

		tagsOfPost.forEach(function (element) {
			const result = tagsList.filter((tagList) => tagList[0] === element);
			arrayOfTag.push(result[0]);
		});

		let i = -1;
		while (++i < arrayOfTag.length) {
			tagsListOfCurrentPost[i] = arrayOfTag[i];
		}
	}

	if (posts && posts[0]) {
		const categoriesOfPost =
			postType === 'tribe_events'
				? posts[0]['tribe_events_cat']
				: posts[0].categories;
		const arrayOfCategorie = [];

		categoriesOfPost.forEach(function (element) {
			const result = categoriesList.filter(
				(categorieList) => categorieList[0] === element
			);

			arrayOfCategorie.push(result[0]);
		});

		let i = -1;
		while (++i < arrayOfCategorie.length) {
			categoriesListOfCurrentPost[i] = arrayOfCategorie[i];
		}
	}

	const thumbnailPost = useSelect((select) => {
		if (posts && posts[0]) {
			const thumbnail = select('core').getMedia(posts[0].featured_media);

			if (thumbnail) {
				return thumbnail;
			}
		}
		return null;
	});

	//Création des tags qui seront ajouté à la classe de la slide
	let tags = '';
	if (tagsListOfCurrentPost[0] !== undefined) {
		tagsListOfCurrentPost.forEach(
			(element) => (tags = tags + ' ' + element[3])
		);
	}

	let startDateFormat;
	let endDateFormat;
	let startHour;
	let endHour;
	let startDateHour;
	let endDateHour;
	let allDay;
	if (posts) {
		const startDate = new Date(posts[0].meta['_EventStartDate']);
		const endDate = new Date(posts[0].meta['_EventEndDate']);
		startDateHour = posts[0].meta['_EventStartDate'];
		startDateFormat = startDate.toLocaleDateString();
		startHour = `${startDate.getHours()}h${String(
			startDate.getMinutes()
		).padStart(2, '0')}`;
		(endDateHour = posts[0].meta['_EventEndDate']),
			(endDateFormat = endDate.toLocaleDateString());
		endHour = `${endDate.getHours()}h${String(
			endDate.getMinutes()
		).padStart(2, '0')}`;
		allDay = posts[0].meta['_EventAllDay'];
	}

	return (
		<Fragment>
			<Inspector
				{...{
					postType,
					interval,
					orderBy,
					showThumbnail,
					showExcerpt,
					showTags,
					perPage,
					nombrePosts,
					perMove,
					autoplay,
					showArrows,
					showPagination,
					setAttributes,
					tagName,
					idTagName,
					tagsList,
					categoriesList,
					allPostType,
					thumbnailSize,
					padding,
					perMoveMobile,
					perPageMobile,
					paddingMobile,
					excludeCurrentPage,
					readMore,
					linkTitle,
					margin,
					categoriesListOfCurrentPost,
					categorieName,
					idCategorieName,
					showCategories,
					tagsListOfCurrentPost,
				}}
			/>
			{posts && postType !== 'temoignage' && (
				<div className="splide" {...blockProps}>
					<div className="splide__track">
						<ul className="splide__list">
							{posts && posts[0] && (
								<li className={`splide__slide ${tags}`}>
									{showThumbnail && thumbnailPost && (
										<figure>
											<img
												src={
													thumbnailPost.media_details
														.sizes[thumbnailSize]
														? thumbnailPost
																.media_details
																.sizes[
																thumbnailSize
														  ].source_url
														: thumbnailPost
																.media_details
																.sizes.full
																.source_url
												}
												alt={thumbnailPost.alt_text}
											/>
										</figure>
									)}
									{posts[0].title.rendered}
									{showExcerpt && posts[0].excerpt && (
										<p
											dangerouslySetInnerHTML={{
												__html: posts[0].excerpt
													.rendered,
											}}
										></p>
									)}

									{posts && postType === 'tribe_events' && (
										<p>
											{startDateFormat &&
												endDateFormat &&
												startDateFormat !==
													endDateFormat &&
												allDay === false && (
													<Fragment>
														Du{' '}
														<time
															className={
																'start_date'
															}
															dateTime={
																startDateHour
															}
														>
															{' '}
															{startDateFormat}
														</time>{' '}
														à
														<time
															className={
																'start_hour'
															}
														>
															{' '}
															{startHour}
														</time>{' '}
														au
														<time
															className={
																'end_date'
															}
															dateTime={
																endDateHour
															}
														>
															{' '}
															{endDateFormat}
														</time>{' '}
														à
														<time
															className={
																'end_hour'
															}
														>
															{' '}
															{endHour}
														</time>
													</Fragment>
												)}

											{startDateFormat &&
												endDateFormat &&
												startDateFormat !==
													endDateFormat &&
												allDay === true && (
													<Fragment>
														Du{' '}
														<time
															className={
																'start_date'
															}
															dateTime={
																startDateHour
															}
														>
															{' '}
															{startDateFormat}
														</time>{' '}
														au
														<time
															className={
																'end_date'
															}
															dateTime={
																endDateHour
															}
														>
															{' '}
															{endDateFormat}
														</time>
													</Fragment>
												)}

											{startDateFormat &&
												endDateFormat &&
												startDateFormat ===
													endDateFormat &&
												allDay === false && (
													<Fragment>
														Le{' '}
														<time
															className={
																'start_date'
															}
															dateTime={
																startDateHour
															}
														>
															{' '}
															{startDateFormat}
														</time>{' '}
														de
														<time
															className={
																'start_hour'
															}
														>
															{' '}
															{startHour}
														</time>{' '}
														à
														<time
															className={
																'end_hour'
															}
															dateTime={
																endDateHour
															}
														>
															{' '}
															{endHour}
														</time>
													</Fragment>
												)}

											{startDateFormat &&
												endDateFormat &&
												startDateFormat ===
													endDateFormat &&
												allDay && (
													<Fragment>
														Le{' '}
														<time
															className={
																'start_date'
															}
															dateTime={
																startDateHour
															}
														>
															{' '}
															{startDateFormat}
														</time>
													</Fragment>
												)}
										</p>
									)}

									{linkTitle}
									<ul className="tags">
										{showTags &&
											tagsList &&
											tagsListOfCurrentPost.length > 0 &&
											tagsListOfCurrentPost.every(
												(element) =>
													element !== undefined
											) &&
											tagsListOfCurrentPost.map((tag) => (
												<li>{tag[1]}</li>
											))}
									</ul>
								</li>
							)}
							{posts[0] === undefined && (
								<p>Il n'y a pas de {postType}</p>
							)}
						</ul>
					</div>
				</div>
			)}

			{posts && postType === 'temoignage' && (
				<div className="splide" {...blockProps}>
					<div className="splide__track">
						<ul className="splide__list">
							{posts && posts[0] && (
								<li className={`splide__slide ${tags}`}>
									{showThumbnail && thumbnailPost && (
										<figure>
											<img
												src={
													thumbnailPost.media_details
														.sizes[thumbnailSize]
														? thumbnailPost
																.media_details
																.sizes[
																thumbnailSize
														  ].source_url
														: thumbnailPost
																.media_details
																.sizes.full
																.source_url
												}
												alt={thumbnailPost.alt_text}
											/>
										</figure>
									)}
									<blockquote className={'wp-block-quote'}>
										<p>{posts[0].acf.texte}</p>
										<cite>
											<span className={'auteur'}>
												{posts[0].acf.auteur}
											</span>
											<span className={'fonction'}>
												{posts[0].acf.fonction}
											</span>
											<span className={'structure'}>
												{posts[0].acf.structure}
											</span>
										</cite>
									</blockquote>
									<ul className="slider_tags">
										{showTags &&
											tagsList &&
											tagsListOfCurrentPost.length > 0 &&
											tagsListOfCurrentPost.every(
												(element) =>
													element !== undefined
											) &&
											tagsListOfCurrentPost.map((tag) => (
												<li>{tag[1]}</li>
											))}
									</ul>
									<ul className="slider_categories">
										{showCategories &&
											categoriesList &&
											tagsListOfCurrentPost.every(
												(element) =>
													element !== undefined
											) &&
											categoriesListOfCurrentPost.map(
												(cat) => <li>{cat[1]}</li>
											)}
									</ul>
								</li>
							)}
						</ul>
					</div>
				</div>
			)}
		</Fragment>
	);
}
