<?php
/**
 * Functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package aster
 * @since 1.0.0
 */

/**
 * The theme version.
 *
 * @since 1.0.0
 */
define( 'ASTER_VERSION', wp_get_theme()->get( 'Version' ) );

/**
 * Add theme support for block styles and editor style.
 *
 * @return void
 * @since 1.0.0
 *
 */
function aster_setup() {
	// Ajoute excerpt dans les pages
	add_post_type_support( 'page', 'excerpt' );

	add_theme_support( 'wp-block-styles' );
	add_editor_style( './assets/css/style-shared.min.css' );
	add_editor_style( './assets/css/editor-style.css' );

	/*
	 * Load additional block styles.
	 * See details on how to add more styles in the readme.txt.
	 */
	$styled_blocks = [ 'quote', 'pullquote', 'search', 'navigation' ];
	foreach ( $styled_blocks as $block_name ) {
		$args = array(
			'handle' => "aster-$block_name",
			'src'    => get_theme_file_uri( "assets/css/blocks/$block_name.min.css" ),
			'path'   => get_theme_file_path( "assets/css/blocks/$block_name.min.css" ),
		);
		// Replace the "core" prefix if you are styling blocks from plugins.
		wp_enqueue_block_style( "core/$block_name", $args );
	}
}

add_action( 'init', 'aster_setup' );

/**
 * Enqueue the CSS files.
 *
 * @return void
 * @since 1.0.0
 *
 */
function aster_styles() {
	wp_enqueue_style(
		'aster-style',
		get_stylesheet_uri(),
		[],
		filemtime( get_template_directory() . '/style.css' )
	);
	wp_enqueue_style(
		'shared-styles',
		get_theme_file_uri( 'assets/css/style-shared.min.css' ),
		[],
		filemtime( get_template_directory() . '/assets/css/style-shared.min.css' )
	);
	wp_enqueue_style(
		'print-style',
		get_theme_file_uri( 'assets/css/print-style.css' ),
		[],
		filemtime( get_template_directory() . '/assets/css/print-style.css' ),
		'print'
	);
	wp_enqueue_script(
		'front-js',
		get_theme_file_uri( '/assets/js/front.js' ),
		array( 'jquery' ),
		filemtime( get_template_directory() . '/assets/js/front.js' ),
		true
	);

}

add_action( 'wp_enqueue_scripts', 'aster_styles' );

function aster_resize_editor_sidebar() {
	wp_enqueue_script(
		'resize-sidebar',
		get_theme_file_uri( 'assets/js/resize-sidebar.js' ),
		array( 'jquery' ),
		filemtime( get_template_directory() . '/assets/js/resize-sidebar.js' ),
		true
	);
}

add_action( 'admin_enqueue_scripts', 'aster_resize_editor_sidebar' );

/**
 * Dequeue les styles de blocs par défaut de wordpress
 *
 * @return void
 * @since 2.2.0
 */
function aster_dequeue_blocks_styles() {
	wp_dequeue_style( 'wp-block-quote' );
	wp_dequeue_style( 'wp-block-post-title' );
	wp_dequeue_style( 'wp-block-pullquote' );

	/* A utiliser au besoin
	wp_dequeue_style( 'wp-block-site-logo' );
	wp_dequeue_style( 'wp-block-group' );
	wp_dequeue_style( 'wp-block-post-title' );
	wp_dequeue_style( 'wp-block-post-date' );
	wp_dequeue_style( 'wp-block-paragraph' );
	wp_dequeue_style( 'wp-block-post-author' );
	wp_dequeue_style( 'wp-block-post-comments-form' );
	wp_dequeue_style( 'wp-block-separator' );
	wp_dequeue_style( 'wp-block-post-excerpt' );
	wp_dequeue_style( 'wp-block-spacer' );
	wp_dequeue_style( 'wp-block-separquery-paginationator' );
	wp_dequeue_style( 'wp-block-social-links' );
	wp_dequeue_style( 'wp-block-library' );
	wp_dequeue_style( 'wp-block-separator' );
	*/

	/* génère des gros bugs d'affichage :
	wp_dequeue_style( 'wp-block-page-list' );
	wp_dequeue_style( 'wp-block-post-template' );
	wp_dequeue_style( 'wp-block-navigation' );
	wp_dequeue_style( 'core-block-supports' );
	wp_dequeue_style( 'global-styles' );
	*/
}

add_action( 'wp_enqueue_scripts', 'aster_dequeue_blocks_styles', 99 );

// Theme update checker.
require_once( 'plugin-update-checker/plugin-update-checker.php' );

use YahnisElsts\PluginUpdateChecker\v5p0\Vcs\GitLabApi;
use YahnisElsts\PluginUpdateChecker\v5p0\Vcs\ThemeUpdateChecker;

$myUpdateChecker = new ThemeUpdateChecker(
	new GitLabApi(
		'https://gitlab.bayard-service.com/wordpress/themes/bsw-aster/',
		'glpat--MKCqQco38yx3Qegwv1k',
		'themes'
	),
	'bsw-aster',
	'bsw-aster'
);

// Stratégie par défaut : on va regarder si une release plus récente existe
$myUpdateChecker->getVcsApi()->enableReleaseAssets();


// Filters.
require_once get_theme_file_path( 'inc/filters.php' );

// Block variation example.
require_once get_theme_file_path( 'inc/register-block-variations.php' );

// Block style examples.
require_once get_theme_file_path( 'inc/register-block-styles.php' );

// Block pattern and block category examples.
require_once get_theme_file_path( 'inc/register-block-patterns.php' );

// Ajout du rôle administrateur de site.
require_once get_theme_file_path( 'inc/site-administrator-role.php' );

// Activation des plugins.
require_once get_theme_file_path( 'inc/plugins-activation.php' );

// Renomme les titres des archives.
require_once get_theme_file_path( 'inc/rename-archive-title.php' );

// Active le support des catégories et tags pour les pages.
require_once get_theme_file_path( 'inc/pages-taxonomies.php' );

// Case à cocher pour exclure les pages de la navigation.
require_once get_theme_file_path( 'inc/exclude-pages-from-nav.php' );

// Ajoute la class de la catégorie sur les posts
// Ajoute la class du parent
require_once get_theme_file_path( 'inc/category-class-post.php' );

// Customisation des mimes types.
require_once get_theme_file_path( 'inc/mime-types.php' );

// Customisation du menu dans le BO.
require_once get_theme_file_path( 'inc/custom-menu.php' );

// Ajout du champ "Contenus en relation".
require_once get_theme_file_path( 'inc/related-contents-field.php' );

//Désactive certains blocks en fonction du rôle de l'utilsateur
add_filter( 'gbm_disabled_blocks', function () {

	$info_role = get_userdata( get_current_user_id() );

	$base_bloc = [
		"core/embed",
		"core-embed/twitter",
		"core-embed/youtube",
		"core-embed/facebook",
		"core-embed/instagram",
		"core-embed/wordpress",
		"core-embed/soundcloud",
		"core-embed/spotify",
		"core-embed/flickr",
		"core-embed/vimeo",
		"core-embed/animoto",
		"core-embed/cloudup",
		"core-embed/collegehumor",
		"core-embed/dailymotion",
		"core-embed/funnyordie",
		"core-embed/hulu",
		"core-embed/imgur",
		"core-embed/issuu",
		"core-embed/kickstarter",
		"core-embed/meetup-com",
		"core-embed/mixcloud",
		"core-embed/photobucket",
		"core-embed/polldaddy",
		"core-embed/reddit",
		"core-embed/reverbnation",
		"core-embed/screencast",
		"core-embed/scribd",
		"core-embed/slideshare",
		"core-embed/smugmug",
		"core-embed/speaker",
		"core-embed/ted",
		"core-embed/tumblr",
		"core-embed/videopress",
		"core-embed/wordpress-tv",
		'core/freeform',
		'core/code',
		'core/preformatted',
		'core/verse',
		'core/more',
		'core/nextpage',
		'core/separator',
		'core/archives',
		'core/calendar',
		'core/categories',
		'core/latest-comments',
		'core/latest-posts',
		'core/rss',
		'core/tag-cloud',
		'core/cover',
		'core/page-list',
		'core/social-links',

	];

	$admin_bloc = [
		'core/group/group',
		'core/group/group-stack',
		'core/group/full-width-group',

		'core/site-logo',
		'core/site-title',
		'core/site-tagline',
		'core/navigation',
		'core/query',
		'core/post-featured-image',
		'core/post-excerpt',
		'core/avatar',
		'core/post-content',
		'core/post-author',
		'core/post-author-name',
		'core/post-title',
		'core/post-date',
		'core/post-terms',
		'core/post-navigation-link',
		'core/post-terms',
		'core/read-more',
		'core/post-comments-form',
		'core/loginout',
		'core/term-description',
		'core/query-title',
		'core/post-author-biography',
		'core/comments',
	];

	if($info_role->roles[0] === 'administrator'){
		return $base_bloc;
	}

	return 	array_merge($base_bloc,$admin_bloc);
} );

function add_tag_class_to_body($classes) {
	global $post;

	if (is_singular()) {
		$post_tags = get_the_terms($post->ID, 'post_tag');

		if ($post_tags && !is_wp_error($post_tags)) {
			foreach ($post_tags as $tag) {
				$classes[] = 'tag-' . $tag->slug;
			}
		}
	}

	return $classes;
}
add_filter('body_class', 'add_tag_class_to_body');
